If pylsl was installed with `pip install pylsl` (recommended), then you can run each of these examples with `python -m pylsl.examples.name_of_example`.

There are few other noteworthy uses of pylsl in the wild. These might give you some inspiration or direct examples of how to use pylsl in your project.

* [mne-realtime examples](https://github.com/mne-tools/mne-realtime/tree/master/examples)
* [NeuroPype](https://www.neuropype.io/)
* [Sig-Visualizer](https://github.com/labstreaminglayer/App-SigVisualizer)
* [Pupil-Labs has 2 different pylsl uses](https://github.com/labstreaminglayer/App-PupilLabs)
* [@agricolab's pyliesl](https://github.com/pyreiz/pyliesl) makes use of some less-common features of LSL and XDF.
* [muse-lsl](https://github.com/alexandrebarachant/muse-lsl)
